import 'package:equatable/equatable.dart';
import 'package:flutter/material.dart';
import 'package:hydrated_bloc/hydrated_bloc.dart';

import 'package:twister/config/default_game_settings.dart';
import 'package:twister/models/settings/settings_game.dart';

part 'settings_game_state.dart';

class GameSettingsCubit extends HydratedCubit<GameSettingsState> {
  GameSettingsCubit() : super(GameSettingsState(settings: GameSettings.createDefault()));

  void setValues({
    String? timerValue,
  }) {
    emit(
      GameSettingsState(
        settings: GameSettings(
          timerValue: timerValue ?? state.settings.timerValue,
        ),
      ),
    );
  }

  String getParameterValue(String code) {
    switch (code) {
      case DefaultGameSettings.parameterCodeTimerValue:
        return GameSettings.getTimerValueFromUnsafe(state.settings.timerValue);
    }

    return '';
  }

  void setParameterValue(String code, String value) {
    final String timerValue = code == DefaultGameSettings.parameterCodeTimerValue
        ? value
        : getParameterValue(DefaultGameSettings.parameterCodeTimerValue);

    setValues(
      timerValue: timerValue,
    );
  }

  @override
  GameSettingsState? fromJson(Map<String, dynamic> json) {
    final String timerValue = json[DefaultGameSettings.parameterCodeTimerValue] as String;

    return GameSettingsState(
      settings: GameSettings(
        timerValue: timerValue,
      ),
    );
  }

  @override
  Map<String, dynamic>? toJson(GameSettingsState state) {
    return <String, dynamic>{
      DefaultGameSettings.parameterCodeTimerValue: state.settings.timerValue,
    };
  }
}
